// Copyright (c) 2012 by István Váradi

// This file is part of libxplcommon, a common utility library for
// development related to X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef XPLCOMMON_LOCALACCEPTOR_H
#define XPLCOMMON_LOCALACCEPTOR_H
//------------------------------------------------------------------------------

#include "Failable.h"

//------------------------------------------------------------------------------

#if 0 // The public interface of a connection acceptor working with local sockets

//------------------------------------------------------------------------------

namespace xplcommon {

//------------------------------------------------------------------------------

/**
 * An acceptor that provides a LocalSocket for each accepted
 * connection.
 */
class LocalAcceptor : public FailableReference<LocalAcceptor>
{
public:

    /**
     * Start accepting a connection.
     *
     * If a connection is already accepted, but not retrieved yet, it
     * returns true.
     *
     * If a new socket becomes immediately available, it returns true.
     *
     * If some error occurs, the acceptor is marked as failed.
     */
    bool accept();

    /**
     * Get the local socket accepted last. If no socket was accepted,
     * return 0. The local socket's waiter will be the given one. If
     * the server socket has no waiter, this one should be 0. If the
     * server socket has a waiter, this one should not be 0. In other
     * words, if the server socket is non-blocking, the accepted one
     * should also be non-blocking, if the server socket is blocking,
     * the accepted one should also be blocking.
     */
    LocalSocket* getSocket(Waiter* waiter,
                           size_t readingCapacity = LocalSocket::DEFAULT_CAPACITY,
                           size_t writingCapacity = LocalSocket::DEFAULT_CAPACITY);
    /**
     * Get the local socket accepted last. If no socket was accepted,
     * return 0. The local socket's waiter will be the same as that of
     * the associated server socket.
     */
    LocalSocket* getSocket(size_t readingCapacity = LocalSocket::DEFAULT_CAPACITY,
                           size_t writingCapacity = LocalSocket::DEFAULT_CAPACITY);
};

//------------------------------------------------------------------------------

} /* namespace xplcommon */

//------------------------------------------------------------------------------

#endif // 0, The public interface of a connection acceptor working with local sockets

//------------------------------------------------------------------------------

#include "config.h"

//------------------------------------------------------------------------------

#if TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "win32/LocalAcceptor.h"

namespace xplcommon { typedef win32::LocalAcceptor LocalAcceptor; }

//------------------------------------------------------------------------------

#else // TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "posix/LocalAcceptor.h"

namespace xplcommon { typedef posix::LocalAcceptor LocalAcceptor; }

//------------------------------------------------------------------------------

#endif // TARGET_API_WIN32

//------------------------------------------------------------------------------
#endif // XPLCOMMON_LOCALACCEPTOR_H

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
