// Copyright (c) 2012 by István Váradi

// This file is part of libxplcommon, a common utility library for
// development related to X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef XPLCOMMON_LOCALCONNECTOR_H
#define XPLCOMMON_LOCALCONNECTOR_H
//------------------------------------------------------------------------------

#include "Failable.h"

//------------------------------------------------------------------------------

#if 0 // The public interface of a connector for a local client socket

//------------------------------------------------------------------------------

namespace xplcommon {

//------------------------------------------------------------------------------

/**
 * Class representing the creation of a connection to some remote
 * entity, like a socket or a pipe. It cannot be created directly,
 * only acquired from a client socket.
 */
class LocalConnector : public FailableReference<LocalConnector>
{
public:
    /**
     * Connect to an address properly set up.
     *
     * If the connection succeeds immediately, it indicates success.
     *
     * If the connection does not succeed, because it would block, it
     * sets up the socket to wait for the connection to succeed, and
     * returns failure.
     *
     * If the connection fails for another reason, the error code is
     * set, and false is returned.
     */
    bool connect();
};

//------------------------------------------------------------------------------

} /* namespace xplcommon */

//------------------------------------------------------------------------------

#endif // 0, The public interface of a connector for a local client socket

//------------------------------------------------------------------------------

#include "config.h"

//------------------------------------------------------------------------------

#if TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "win32/LocalConnector.h"

namespace xplcommon { typedef win32::LocalConnector LocalConnector; }

//------------------------------------------------------------------------------

#else // TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "posix/LocalConnector.h"

namespace xplcommon { typedef posix::LocalConnector LocalConnector; }

//------------------------------------------------------------------------------

#endif // TARGET_API_WIN32

//------------------------------------------------------------------------------
#endif // XPLCOMMON_LOCALCONNECTOR_H

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
